#!/bin/bash

set +e
eth_port_name=$(ip route show default | awk '/default via/ {print $5; exit}')
if [[ $eth_port_name == '' ]]; then
    echo 'Could not find route default $eth_port_name, device mode setup failed!'
    exit 1
fi
echo 'Found route default' $eth_port_name', setting up device mode'
setup_t='192.168.55.0/24'
sudo iptables -t nat -A POSTROUTING -s $setup_t -o $eth_port_name -j MASQUERADE
sudo iptables -A FORWARD -s $setup_t -o $eth_port_name -j ACCEPT
sudo iptables -A FORWARD -d $setup_t -m state --state ESTABLISHED,RELATED -i $eth_port_name -j ACCEPT
sudo sysctl -w net.ipv4.ip_forward=1
check_google_dns=$(dig @8.8.8.8 nvidia.com || true)
if [[ $check_google_dns == *'Got answer'* ]]; then
    echo 'Device mode on host successfully set with DNS 8.8.8.8!'
    exit 0
else
    echo 'Default google DNS is not working, trying to find a valid server in local host settings!'
    dns_list=$(nmcli -t device show $eth_port_name | grep 'DNS' | grep -o '[^:]*$')
    if [[ -z "$dns_list" ]]; then
        echo 'Could not get DNS server with nmcli, tring to use resolvectl...'
        dns_list=$(resolvectl dns $eth_port_name | awk -F ': ' '{print $2}')
    fi
    for dns in $dns_list; do
        check_dns=$(dig @$dns nvidia.com || true)
        if [[ $check_dns == *'Got answer'* ]]; then
            sudo iptables -t nat -A PREROUTING -p tcp -d 8.8.8.8 --dport 53 -j DNAT --to-destination $dns
            sudo iptables -t nat -A PREROUTING -p udp -d 8.8.8.8 --dport 53 -j DNAT --to-destination $dns
            echo 'Device mode on host successfully set with DNS' $dns'!'
            exit 0
        fi
    done
    echo 'Could not find a valid DNS server, device mode setup failed!'
    echo 'If needed to use device mode, please change the target default dns to a valid server by following the steps in release note.'
    exit 1
fi