unset PS1
unset PROMPT_COMMAND
unset HISTFILE
stty -echo
export LC_ALL=en_US.UTF-8 LANG=en_US.UTF-8 LANGUAGE=en_US.UTF-8 SUDO_PROMPT='[host] [sudo] password for %u: '
export DEBIAN_FRONTEND=noninteractive

# Collect UART logs from connected debug port during flash
# Usage: collect_uart_logs <function_name> <output_file>
collect_uart_logs() {
    set +e
    if [ -z "$1" ] || [ -z "$2" ]; then
        echo "Usage: collect_uart_logs <function_name> <output_file>"
        return 1
    fi

    local function_name="$1"
    local output_file="$2"

    local collecting_device=""
    for device in /dev/tty*; do
        if (udevadm info "$device" | grep -q 'ID_MODEL_ID=7045'); then
            sudo -v
            if sudo lsof "$device" &> /dev/null; then
                echo "Skipping UART log collection on $device, already in use"
            else
                echo "Found connected debug port on $device"
                sudo cat $device > "$output_file" &
                echo "Collecting UART logs from $device to $output_file [PID $!]"
                collecting_device="$device"
            fi
            break
        fi
    done

    $function_name
    local exit_code=$?

    if [ -n "$collecting_device" ]; then
        if sudo lsof "$collecting_device" &> /dev/null; then
            echo "Terminating UART logs collection"
            sudo kill -9 $(sudo lsof -t "$collecting_device") || true
        else
            echo "Failed to collect UART logs, process not found"
        fi
    fi
    echo "Exiting with code $exit_code"
    return $exit_code
}
export -f collect_uart_logs
