param (
    [Parameter()]
    [string]$Name,
    [int]$Interval = 5
)

if (-not $Name) {
    Write-Host "Error: Name parameter is required."
    Exit 1
}

function ConvertTo-Int32 {
    param ([uint32]$uintValue)
    if ($uintValue -gt [int32]::MaxValue) {
        return [int32]($uintValue - [uint32]::MaxValue - 1)
    } else {
        return [int32]$uintValue
    }
}

# Check if the task exists
if (Get-ScheduledTask -TaskName $Name -ErrorAction SilentlyContinue) {
    # Start the scheduled task
    Start-ScheduledTask -TaskName $Name
    # Define timeout parameters
    $timeoutSeconds = 1200  # Set timeout for 20 minutes
    $timer = [Diagnostics.Stopwatch]::StartNew()

    # Wait for the task to complete
    while ((Get-ScheduledTask -TaskName $Name).State -eq 'Running' -and $timer.Elapsed.TotalSeconds -lt $timeoutSeconds) {
        # Check every 5 seconds
        Start-Sleep -Seconds $Interval
    }

    # Stop the timer
    $timer.Stop()

    If ($timer.Elapsed.TotalSeconds -ge $timeoutSeconds) {
        # TODO: Handle timeout
        Write-Host "Timeout reached. Task is still running."
    } Else {
        # Write-Host "Task '$Name' completed."
        $lastTaskResult = (Get-ScheduledTaskInfo -TaskName $Name).LastTaskResult
        # Task scheduler returns unsigned int (uint32) but PowerShell expects signed int (int32) for exit codes
        $int32Result = ConvertTo-Int32 $lastTaskResult
        Exit $int32Result
    }
} else {
    Write-Host "Error: Task '$Name' does not exist."
    Exit 1
}